@@ -6,7 +6,7 @@ use Carp qw/croak carp confess/;
 use File::ShareDir qw/dist_dir/;
 use Path::Tiny;
 
-our $VERSION = '0.0.10';
+our $VERSION = '0.0.12';
 
 sub _split_sql {
     my $input = shift;
@@ -57,6 +57,9 @@ sub _split_sql {
         }
     }
 
+    foreach my $item (@items) {
+        $item->{sql} =~ s/;[\s\n]*$//;
+    }
     return \@items;
 }
 
